@@ -3,8 +3,11 @@ import hmac
 import json
 
 import requests
+from requests.auth import HTTPBasicAuth
 from rest_framework.utils.encoders import JSONEncoder
 
+from whisperer.conf import settings
+
 
 class WebhookClient(object):
     def __init__(self, event_type, payload):
@@ -31,15 +34,29 @@ class WebhookClient(object):
         payload,
         secret_key=None,
         additional_headers=None,
+        auth_config=None,
         *args,
         **kwargs
     ):
         payload = json.dumps(payload, cls=JSONEncoder)
+        auth = None
         if secret_key:
             self.sign(secret_key, payload)
+        if auth_config:
+            auth = self._get_auth(auth_config)
         if additional_headers:
             self.headers.update(additional_headers)
         response = requests.post(
-            url=target_url, data=payload, headers=self.headers, timeout=10
+            url=target_url,
+            data=payload,
+            headers=self.headers,
+            timeout=settings.WHISPERER_REQUEST_TIMEOUT,
+            auth=auth,
         )
         return response
+
+    def _get_auth(self, auth_config):
+        if auth_config.get('auth_type') == 'basic':
+            username = auth_config.get('username')
+            password = auth_config.get('password')
+            return HTTPBasicAuth(username, password)
