@@ -11,12 +11,20 @@ class OrderCreateEvent(WhispererEvent):
     event_type = 'order-created'
 
 
+class OrderUpdateEvent(WhispererEvent):
+    serializer_class = OrderSerializer
+    event_type = 'order-updated'
+
+
 registry.register(OrderCreateEvent)
+registry.register(OrderUpdateEvent)
 
 
 def signal_receiver(instance, created=False, **kwargs):
     if created:
-        deliver_event(instance, 'order-created', False)
+        deliver_event(instance, 'order-created')
+    else:
+        deliver_event(instance, 'order-updated')
 
 
 post_save.connect(signal_receiver, Order)
